@@ -15,9 +15,16 @@
 
 int getAnimationFrame(int, int, int, int, int);
 
+void InitGlobalAnimEventsForCustomElements(void);
 void InitGlobalAnimations(void);
 void DrawGlobalAnimations(int, int);
 
+void RestartGlobalAnimsByStatus(int);
+void SetAnimStatusBeforeFading(int);
+
 boolean HandleGlobalAnimClicks(int, int, int, boolean);
+void HandleGlobalAnimEventByElementChange(int, int, int, int, int, int);
+
+int getGlobalAnimSyncFrame(void);
 
 #endif
