@@ -40,6 +40,7 @@ static DelayCounter special_cursor_delay = { 1000 };
 static boolean special_cursor_enabled = FALSE;
 
 static boolean stop_processing_events = FALSE;
+static boolean is_global_anim_event = FALSE;
 
 
 // forward declarations for internal use
@@ -1551,6 +1552,15 @@ static int HandleDropFileEvent(char *filename)
   // add extracted level or artwork set to tree info structure
   AddTreeSetToTreeInfo(tree_node, directory, top_dir, tree_type);
 
+  // force restart after adding level collection
+  if (getTreeInfoFromIdentifier(TREE_FIRST_NODE(tree_type), top_dir) == NULL)
+  {
+    Request("Program must be restarted after adding a new level collection!",
+	    REQ_CONFIRM);
+
+    CloseAllAndExit(0);
+  }
+
   // update menu screen (and possibly change current level set)
   DrawScreenAfterAddingSet(top_dir, tree_type);
 
@@ -2204,6 +2214,10 @@ void HandleKey(Key key, int key_status)
     // reset flag to ignore repeated "key pressed" events after key release
     ignore_repeated_key = FALSE;
 
+    // send key release event to global animation event handling
+    if (!is_global_anim_event)
+      HandleGlobalAnimClicks(-1, -1, KEY_RELEASED, FALSE);
+
     return;
   }
 
@@ -2259,9 +2273,9 @@ void HandleKey(Key key, int key_status)
   }
 
   // some key events are handled like clicks for global animations
-  boolean click = (key == KSYM_space ||
-		   key == KSYM_Return ||
-		   key == KSYM_Escape);
+  boolean click = (!is_global_anim_event && (key == KSYM_space ||
+					     key == KSYM_Return ||
+					     key == KSYM_Escape));
 
   if (click && HandleGlobalAnimClicks(-1, -1, MB_LEFTBUTTON, TRUE))
   {
@@ -2553,14 +2567,14 @@ static void HandleTileCursor(int dx, int dy, int button)
   {
     int old_xpos = tile_cursor.xpos;
     int old_ypos = tile_cursor.ypos;
-    int new_xpos = old_xpos;
-    int new_ypos = old_ypos;
+    int new_xpos = tile_cursor.xpos + dx;
+    int new_ypos = tile_cursor.ypos + dy;
 
-    if (IN_LEV_FIELD(old_xpos + dx, old_ypos))
-      new_xpos = old_xpos + dx;
+    if (!IN_LEV_FIELD(new_xpos, old_ypos) || !IN_SCR_FIELD(new_xpos, old_ypos))
+      new_xpos = old_xpos;
 
-    if (IN_LEV_FIELD(old_xpos, old_ypos + dy))
-      new_ypos = old_ypos + dy;
+    if (!IN_LEV_FIELD(old_xpos, new_ypos) || !IN_SCR_FIELD(old_xpos, new_ypos))
+      new_ypos = old_ypos;
 
     SetTileCursorTargetXY(new_xpos, new_ypos);
   }
@@ -2614,12 +2628,15 @@ void HandleJoystick(void)
   int up	= joy & JOY_UP;
   int down	= joy & JOY_DOWN;
   int button	= joy & JOY_BUTTON;
-  int newbutton	= (AnyJoystickButton() == JOY_BUTTON_NEW_PRESSED);
+  int anybutton = AnyJoystickButton();
+  int newbutton	= (anybutton == JOY_BUTTON_NEW_PRESSED);
   int dx	= (left ? -1	: right ? 1	: 0);
   int dy	= (up   ? -1	: down  ? 1	: 0);
   boolean use_delay_value_first = (joytest != joytest_last);
+  boolean new_button_event = (anybutton == JOY_BUTTON_NEW_PRESSED ||
+			      anybutton == JOY_BUTTON_NEW_RELEASED);
 
-  if (HandleGlobalAnimClicks(-1, -1, newbutton, FALSE))
+  if (new_button_event && HandleGlobalAnimClicks(-1, -1, newbutton, FALSE))
   {
     // do not handle this button event anymore
     return;
@@ -2818,9 +2835,13 @@ boolean DoKeysymAction(int keysym)
   {
     Key key = (Key)(-keysym);
 
+    is_global_anim_event = TRUE;
+
     HandleKey(key, KEY_PRESSED);
     HandleKey(key, KEY_RELEASED);
 
+    is_global_anim_event = FALSE;
+
     return TRUE;
   }
 
