@@ -35,9 +35,6 @@ char *getGlobalLevelTemplateFilename(void);
 
 int getMappedElement(int);
 
-void ExecuteAsThread(SDL_ThreadFunction, char *, void *, char *);
-char *getPasswordJSON(char *);
-
 void LoadLevelFromFilename(struct LevelInfo *, char *);
 void LoadLevel(int);
 void LoadLevelTemplate(int);
@@ -56,6 +53,8 @@ void CopyNativeLevel_Native_to_RND(struct LevelInfo *);
 void LoadTapeFromFilename(char *);
 void LoadTape(int);
 void LoadSolutionTape(int);
+void LoadScoreTape(char *, int);
+void LoadScoreCacheTape(char *, int);
 void SaveTapeToFilename(char *);
 void SaveTape(int);
 void SaveScoreTape(int);
@@ -73,6 +72,8 @@ void SaveServerScoreFromFile(int, boolean, char *);
 
 void LoadLocalAndServerScore(int, boolean);
 
+void PrepareScoreTapesForUpload(char *);
+
 void LoadUserNames(void);
 
 void LoadSetupFromFilename(char *);
@@ -98,6 +99,7 @@ void removeHideSetupEntry(void *);
 boolean hideSetupEntry(void *);
 
 void LoadCustomElementDescriptions(void);
+void InitMenuDesignSettings_FromHash(SetupFileHash *, boolean);
 void InitMenuDesignSettings_Static(void);
 void LoadMenuDesignSettings(void);
 void LoadMenuDesignSettings_AfterGraphics(void);
